{% extends 'leprikon/base.html' %}
{% load cms_tags i18n leprikon_tags %}

{% block content %}

<h1>{% block title %}{{ title|first_upper }}{% endblock %}</h1>

{% if placeholder %}
{% static_placeholder placeholder %}
{% endif %}

{% if form %}
{% include 'leprikon/filter_form.html' %}
{% endif %}

{% if add_url %}
<a class="btn btn-sm btn-primary right" href="{{ add_url }}" title="{{ add_title }}">
    <span class="glyphicon glyphicon-plus"></span>
    {{ add_label }}
</a>
{% endif %}

{% include 'leprikon/pagination.html' %}

{% block list %}
{% for object in object_list %}
{% include preview_template %}
{% empty %}
<p>{{ message_empty }}</p>
{% endfor %}
{% endblock %}

{% include 'leprikon/pagination.html' %}

{% endblock %}
